@@ -1,10 +1,7 @@
 import esphome.codegen as cg
-import esphome.config_validation as cv
 from esphome.components import airthings_wave_base
-
-from esphome.const import (
-    CONF_ID,
-)
+import esphome.config_validation as cv
+from esphome.const import CONF_ID
 
 DEPENDENCIES = airthings_wave_base.DEPENDENCIES
 
