@@ -1,7 +1,7 @@
 import esphome.codegen as cg
 from esphome.components import ble_client, cover
 import esphome.config_validation as cv
-from esphome.const import CONF_ID, CONF_PIN
+from esphome.const import CONF_PIN
 
 CODEOWNERS = ["@buxtronix"]
 DEPENDENCIES = ["ble_client"]
@@ -15,9 +15,9 @@ Am43Component = am43_ns.class_(
 )
 
 CONFIG_SCHEMA = (
-    cover.COVER_SCHEMA.extend(
+    cover.cover_schema(Am43Component)
+    .extend(
         {
-            cv.GenerateID(): cv.declare_id(Am43Component),
             cv.Optional(CONF_PIN, default=8888): cv.int_range(min=0, max=0xFFFF),
             cv.Optional(CONF_INVERT_POSITION, default=False): cv.boolean,
         }
@@ -28,9 +28,8 @@ CONFIG_SCHEMA = (
 
 
 async def to_code(config):
-    var = cg.new_Pvariable(config[CONF_ID])
+    var = await cover.new_cover(config)
     cg.add(var.set_pin(config[CONF_PIN]))
     cg.add(var.set_invert_position(config[CONF_INVERT_POSITION]))
     await cg.register_component(var, config)
-    await cover.register_cover(var, config)
     await ble_client.register_ble_node(var, config)
