@@ -64,7 +64,7 @@ bool DallasTemperatureSensor::read_scratch_pad_() {
     }
   } else {
     ESP_LOGW(TAG, "'%s' - reading scratch pad failed bus reset", this->get_name().c_str());
-    this->status_set_warning("bus reset failed");
+    this->status_set_warning(LOG_STR("bus reset failed"));
   }
   return success;
 }
@@ -124,7 +124,7 @@ bool DallasTemperatureSensor::check_scratch_pad_() {
             crc8(this->scratch_pad_, 8));
 #endif
   if (!chksum_validity) {
-    this->status_set_warning("scratch pad checksum invalid");
+    this->status_set_warning(LOG_STR("scratch pad checksum invalid"));
     ESP_LOGD(TAG, "Scratch pad: %02X.%02X.%02X.%02X.%02X.%02X.%02X.%02X.%02X (%02X)", this->scratch_pad_[0],
              this->scratch_pad_[1], this->scratch_pad_[2], this->scratch_pad_[3], this->scratch_pad_[4],
              this->scratch_pad_[5], this->scratch_pad_[6], this->scratch_pad_[7], this->scratch_pad_[8],
