@@ -1,7 +1,13 @@
 #include "factory_reset_switch.h"
+
+#include "esphome/core/defines.h"
+
+#ifdef USE_OPENTHREAD
+#include "esphome/components/openthread/openthread.h"
+#endif
+#include "esphome/core/application.h"
 #include "esphome/core/hal.h"
 #include "esphome/core/log.h"
-#include "esphome/core/application.h"
 
 namespace esphome {
 namespace factory_reset {
@@ -17,10 +23,21 @@ void FactoryResetSwitch::write_state(bool state) {
     ESP_LOGI(TAG, "Resetting");
     // Let MQTT settle a bit
     delay(100);  // NOLINT
+#ifdef USE_OPENTHREAD
+    openthread::global_openthread_component->on_factory_reset(FactoryResetSwitch::factory_reset_callback);
+#else
     global_preferences->reset();
     App.safe_reboot();
+#endif
   }
 }
 
+#ifdef USE_OPENTHREAD
+void FactoryResetSwitch::factory_reset_callback() {
+  global_preferences->reset();
+  App.safe_reboot();
+}
+#endif
+
 }  // namespace factory_reset
 }  // namespace esphome
