@@ -39,18 +39,22 @@ ErrorCode I2CDevice::read_register16(uint16_t a_register, uint8_t *data, size_t
 }
 
 ErrorCode I2CDevice::write_register(uint8_t a_register, const uint8_t *data, size_t len) const {
-  std::vector<uint8_t> v{};
-  v.push_back(a_register);
-  v.insert(v.end(), data, data + len);
-  return bus_->write_readv(this->address_, v.data(), v.size(), nullptr, 0);
+  SmallBufferWithHeapFallback<17> buffer_alloc;  // Most I2C writes are <= 16 bytes
+  uint8_t *buffer = buffer_alloc.get(len + 1);
+
+  buffer[0] = a_register;
+  std::copy(data, data + len, buffer + 1);
+  return this->bus_->write_readv(this->address_, buffer, len + 1, nullptr, 0);
 }
 
 ErrorCode I2CDevice::write_register16(uint16_t a_register, const uint8_t *data, size_t len) const {
-  std::vector<uint8_t> v(len + 2);
-  v[0] = a_register >> 8;
-  v[1] = a_register;
-  std::copy(data, data + len, v.begin() + 2);
-  return bus_->write_readv(this->address_, v.data(), v.size(), nullptr, 0);
+  SmallBufferWithHeapFallback<18> buffer_alloc;  // Most I2C writes are <= 16 bytes + 2 for register
+  uint8_t *buffer = buffer_alloc.get(len + 2);
+
+  buffer[0] = a_register >> 8;
+  buffer[1] = a_register;
+  std::copy(data, data + len, buffer + 2);
+  return this->bus_->write_readv(this->address_, buffer, len + 2, nullptr, 0);
 }
 
 bool I2CDevice::read_bytes_16(uint8_t a_register, uint16_t *data, uint8_t len) {
