@@ -1,4 +1,3 @@
-import esphome.codegen as cg
 from esphome.components.binary_sensor import (
     BinarySensor,
     binary_sensor_schema,
@@ -6,36 +5,30 @@ from esphome.components.binary_sensor import (
 )
 import esphome.config_validation as cv
 
-from ..defines import CONF_LVGL_ID, CONF_WIDGET
-from ..lvcode import EVENT_ARG, LambdaContext, LvContext
-from ..schemas import LVGL_SCHEMA
+from ..defines import CONF_WIDGET
+from ..lvcode import EVENT_ARG, LambdaContext, LvContext, lvgl_static
 from ..types import LV_EVENT, lv_pseudo_button_t
 from ..widgets import Widget, get_widgets, wait_for_widgets
 
-CONFIG_SCHEMA = (
-    binary_sensor_schema(BinarySensor)
-    .extend(LVGL_SCHEMA)
-    .extend(
-        {
-            cv.Required(CONF_WIDGET): cv.use_id(lv_pseudo_button_t),
-        }
-    )
+CONFIG_SCHEMA = binary_sensor_schema(BinarySensor).extend(
+    {
+        cv.Required(CONF_WIDGET): cv.use_id(lv_pseudo_button_t),
+    }
 )
 
 
 async def to_code(config):
     sensor = await new_binary_sensor(config)
-    paren = await cg.get_variable(config[CONF_LVGL_ID])
     widget = await get_widgets(config, CONF_WIDGET)
     widget = widget[0]
     assert isinstance(widget, Widget)
     await wait_for_widgets()
     async with LambdaContext(EVENT_ARG) as pressed_ctx:
         pressed_ctx.add(sensor.publish_state(widget.is_pressed()))
-    async with LvContext(paren) as ctx:
+    async with LvContext() as ctx:
         ctx.add(sensor.publish_initial_state(widget.is_pressed()))
         ctx.add(
-            paren.add_event_cb(
+            lvgl_static.add_event_cb(
                 widget.obj,
                 await pressed_ctx.get_lambda(),
                 LV_EVENT.PRESSING,
