@@ -1,12 +1,17 @@
 from esphome import automation
 import esphome.codegen as cg
-from esphome.const import CONF_ID, CONF_ON_BOOT, CONF_ON_VALUE, CONF_TRIGGER_ID
+from esphome.const import (
+    CONF_ID,
+    CONF_ON_BOOT,
+    CONF_ON_VALUE,
+    CONF_TRIGGER_ID,
+    CONF_X,
+    CONF_Y,
+)
 
 from .defines import (
     CONF_ALIGN,
     CONF_ALIGN_TO,
-    CONF_X,
-    CONF_Y,
     DIRECTIONS,
     LV_EVENT_MAP,
     LV_EVENT_TRIGGERS,
