@@ -12,7 +12,6 @@ static const uint8_t SENSOR_REGISTER = 0x04;
 static const uint8_t POWER_MODE_REGISTER = 0x0a;
 
 void MICS4514Component::setup() {
-  ESP_LOGCONFIG(TAG, "Running setup");
   uint8_t power_mode;
   this->read_register(POWER_MODE_REGISTER, &power_mode, 1);
   if (power_mode == 0x00) {
@@ -20,16 +19,12 @@ void MICS4514Component::setup() {
     power_mode = 0x01;
     this->write_register(POWER_MODE_REGISTER, &power_mode, 1);
     delay(100);  // NOLINT
-    this->set_timeout("warmup", 3 * 60 * 1000, [this]() {
-      this->warmed_up_ = true;
-      ESP_LOGCONFIG(TAG, "MICS 4514 setup complete.");
-    });
+    this->set_timeout("warmup", 3 * 60 * 1000, [this]() { this->warmed_up_ = true; });
     this->status_set_warning();
     return;
   }
   ESP_LOGCONFIG(TAG, "Device already awake.");
   this->warmed_up_ = true;
-  ESP_LOGCONFIG(TAG, "MICS 4514 setup complete.");
 }
 void MICS4514Component::dump_config() {
   ESP_LOGCONFIG(TAG, "MICS 4514:");
