@@ -38,8 +38,10 @@ void MQTTLockComponent::dump_config() {
 std::string MQTTLockComponent::component_type() const { return "lock"; }
 const EntityBase *MQTTLockComponent::get_entity() const { return this->lock_; }
 void MQTTLockComponent::send_discovery(JsonObject root, mqtt::SendDiscoveryConfig &config) {
-  if (this->lock_->traits.get_assumed_state())
+  // NOLINTNEXTLINE(clang-analyzer-cplusplus.NewDeleteLeaks) false positive with ArduinoJson
+  if (this->lock_->traits.get_assumed_state()) {
     root[MQTT_OPTIMISTIC] = true;
+  }
   if (this->lock_->traits.get_supports_open())
     root[MQTT_PAYLOAD_OPEN] = "OPEN";
 }
