@@ -28,7 +28,6 @@ namespace esphome {
 namespace openthread {
 
 void OpenThreadComponent::setup() {
-  ESP_LOGCONFIG(TAG, "Running setup");
   // Used eventfds:
   // * netif
   // * ot task queue
@@ -144,10 +143,13 @@ void OpenThreadComponent::ot_main() {
   esp_openthread_launch_mainloop();
 
   // Clean up
+  esp_openthread_deinit();
   esp_openthread_netif_glue_deinit();
   esp_netif_destroy(openthread_netif);
 
   esp_vfs_eventfd_unregister();
+  this->teardown_complete_ = true;
+  vTaskDelete(NULL);
 }
 
 network::IPAddresses OpenThreadComponent::get_ip_addresses() {
