@@ -1,8 +1,8 @@
 #pragma once
 
-#include "esphome/core/component.h"
-#include "esphome/components/sensor/sensor.h"
 #include "esphome/components/sensirion_common/i2c_sensirion.h"
+#include "esphome/components/sensor/sensor.h"
+#include "esphome/core/component.h"
 #include "esphome/core/preferences.h"
 
 #include <cinttypes>
@@ -38,14 +38,16 @@ class SGP30Component : public PollingComponent, public sensirion_common::Sensiri
   void read_iaq_baseline_();
   bool is_sensor_baseline_reliable_();
   void write_iaq_baseline_(uint16_t eco2_baseline, uint16_t tvoc_baseline);
+
   uint64_t serial_number_;
-  uint16_t featureset_;
   uint32_t required_warm_up_time_;
   uint32_t seconds_since_last_store_;
-  SGP30Baselines baselines_storage_;
-  ESPPreferenceObject pref_;
+  uint16_t featureset_;
+  uint16_t eco2_baseline_{0x0000};
+  uint16_t tvoc_baseline_{0x0000};
+  bool store_baseline_;
 
-  enum ErrorCode {
+  enum ErrorCode : uint8_t {
     COMMUNICATION_FAILED,
     MEASUREMENT_INIT_FAILED,
     INVALID_ID,
@@ -53,14 +55,13 @@ class SGP30Component : public PollingComponent, public sensirion_common::Sensiri
     UNKNOWN
   } error_code_{UNKNOWN};
 
+  ESPPreferenceObject pref_;
+  SGP30Baselines baselines_storage_;
+
   sensor::Sensor *eco2_sensor_{nullptr};
   sensor::Sensor *tvoc_sensor_{nullptr};
   sensor::Sensor *eco2_sensor_baseline_{nullptr};
   sensor::Sensor *tvoc_sensor_baseline_{nullptr};
-  uint16_t eco2_baseline_{0x0000};
-  uint16_t tvoc_baseline_{0x0000};
-  bool store_baseline_;
-
   /// Input sensor for humidity and temperature compensation.
   sensor::Sensor *humidity_sensor_{nullptr};
   sensor::Sensor *temperature_sensor_{nullptr};
