@@ -25,6 +25,7 @@ class TouchscreenBinarySensor : public binary_sensor::BinarySensor,
     this->y_min_ = y_min;
     this->y_max_ = y_max;
   }
+  void set_use_raw(bool use_raw) { this->use_raw_ = use_raw; }
   int16_t get_x_min() { return this->x_min_; }
   int16_t get_x_max() { return this->x_max_; }
   int16_t get_y_min() { return this->y_min_; }
@@ -38,7 +39,8 @@ class TouchscreenBinarySensor : public binary_sensor::BinarySensor,
   void release() override;
 
  protected:
-  int16_t x_min_, x_max_, y_min_, y_max_;
+  int16_t x_min_{}, x_max_{}, y_min_{}, y_max_{};
+  bool use_raw_{};
   std::vector<display::DisplayPage *> pages_{};
 };
 
