@@ -44,9 +44,11 @@ void TuyaSelect::control(const std::string &value) {
 
 void TuyaSelect::dump_config() {
   LOG_SELECT("", "Tuya Select", this);
-  ESP_LOGCONFIG(TAG, "  Select has datapoint ID %u", this->select_id_);
-  ESP_LOGCONFIG(TAG, "  Data type: %s", this->is_int_ ? "int" : "enum");
-  ESP_LOGCONFIG(TAG, "  Options are:");
+  ESP_LOGCONFIG(TAG,
+                "  Select has datapoint ID %u\n"
+                "  Data type: %s\n"
+                "  Options are:",
+                this->select_id_, this->is_int_ ? "int" : "enum");
   auto options = this->traits.get_options();
   for (auto i = 0; i < this->mappings_.size(); i++) {
     ESP_LOGCONFIG(TAG, "    %i: %s", this->mappings_.at(i), options.at(i).c_str());
