@@ -7,7 +7,7 @@ namespace uart {
 static const char *const TAG = "uart.button";
 
 void UARTButton::press_action() {
-  ESP_LOGD(TAG, "'%s': Sending data...", this->get_name().c_str());
+  ESP_LOGD(TAG, "'%s': Sending data", this->get_name().c_str());
   this->write_array(this->data_.data(), this->data_.size());
 }
 
