@@ -1,7 +1,7 @@
 import esphome.codegen as cg
 from esphome.components import climate_ir
 import esphome.config_validation as cv
-from esphome.const import CONF_ID, CONF_USE_FAHRENHEIT
+from esphome.const import CONF_USE_FAHRENHEIT
 
 AUTO_LOAD = ["climate_ir"]
 
@@ -9,15 +9,13 @@ whynter_ns = cg.esphome_ns.namespace("whynter")
 Whynter = whynter_ns.class_("Whynter", climate_ir.ClimateIR)
 
 
-CONFIG_SCHEMA = climate_ir.CLIMATE_IR_WITH_RECEIVER_SCHEMA.extend(
+CONFIG_SCHEMA = climate_ir.climate_ir_with_receiver_schema(Whynter).extend(
     {
-        cv.GenerateID(): cv.declare_id(Whynter),
         cv.Optional(CONF_USE_FAHRENHEIT, default=False): cv.boolean,
     }
 )
 
 
 async def to_code(config):
-    var = cg.new_Pvariable(config[CONF_ID])
-    await climate_ir.register_climate_ir(var, config)
+    var = await climate_ir.new_climate_ir(config)
     cg.add(var.set_fahrenheit(config[CONF_USE_FAHRENHEIT]))
